==> nextcloud-14.0.1.tgz: nextcloud/apps/comments/l10n/he.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "עריכת תגובה",
    "Delete comment" : "מחיקת תגובה",
    "New comment …" : "תגובה חדשה",
    "Post" : "פרסום",
    "Cancel" : "ביטול",
    "[Deleted user]" : "[משתמשים מוסרים]",
    "Comments" : "תגובות",
    "No comments yet, start the conversation!" : "אין תגובות עדיין, בואו נתחיל לקשקש!",
    "More comments …" : "תגובות נוספות…",
    "Save" : "שמירה",
    "Allowed characters {count} of {max}" : "תווים מותרים {count} מתוך {max}",
    "Error occurred while retrieving comment with ID {id}" : "אירעה שגיאה בעת קבלת התגובה עם המזהה {id}",
    "Error occurred while updating comment with id {id}" : "שגיאה אירעה כאשר עודכנה תגובה עם מספר זיהוי {id}",
    "Error occurred while posting comment" : "אירעה שגיאה בזמן פרסום תגובה",
    "_%n unread comment_::_%n unread comments_" : ["תגובה אחת שלא נקראה","%n תגובות שלא נקראו","%n תגובות שלא נקראו","%n תגובות שלא נקראו"],
    "Comment" : "תגובה",
    "You commented" : "הערות שלך",
    "%1$s commented" : "התקבלו תגובות %1$s",
    "{author} commented" : "התקבלה תגובה מאת {author}",
    "You commented on %1$s" : "הגבת על %1$s",
    "You commented on {file}" : "הגבת על {file}",
    "%1$s commented on %2$s" : "התקבלו תגובות %1$s ב- %2$s ",
    "{author} commented on {file}" : "נוספה תגובה על {file} מאת {author}",
    "<strong>Comments</strong> for files" : "<strong>תגובות</strong> על קבצים",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "אוזכרת ב־„%s”, בתגובה על ידי משתמש שנמחק בינתיים.",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "אוזכרת ב־„{file}”, בתגובה של משתמש שנמחק בינתיים.",
    "%1$s mentioned you in a comment on “%2$s”" : "אוזכרת על ידי %1$s בתגובה על „%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "אוזכרת על ידי „{user}” בתגובה על „{file}”",
    "Unknown user" : "משתמש לא ידוע",
    "A (now) deleted user mentioned you in a comment on “%s”" : "אוזכרת על ידי משתמש שנמחק (נכון לעכשיו) בתגובה על „%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "אוזכרת על ידי משתמש שנמחק (נכון לעכשיו) בתגובה על „{file}”"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-20.0.12.tgz: nextcloud/apps/comments/l10n/he.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "תגובות",
    "You commented" : "הערות שלך",
    "%1$s commented" : "התקבלו תגובות %1$s",
    "{author} commented" : "התקבלה תגובה מאת {author}",
    "You commented on %1$s" : "הגבת על %1$s",
    "You commented on {file}" : "הגבת על {file}",
    "%1$s commented on %2$s" : "התקבלו תגובות %1$s ב- %2$s ",
    "{author} commented on {file}" : "נוספה תגובה על {file} מאת {author}",
    "<strong>Comments</strong> for files" : "<strong>תגובות</strong> על קבצים",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "אוזכרת ב־„{file}”, בתגובה של משתמש שנמחק בינתיים.",
    "{user} mentioned you in a comment on “{file}”" : "אוזכרת על ידי „{user}” בתגובה על „{file}”",
    "Files app plugin to add comments to files" : "תוסף ליישומון הקבצים כדי להוסיף הערות על קבצים",
    "Edit comment" : "עריכת תגובה",
    "Delete comment" : "מחיקת תגובה",
    "Cancel edit" : "בטל עריכה",
    "Post comment" : "פרסם תגובה",
    "No comments yet, start the conversation!" : "אין תגובות עדיין, בואו נתחיל לקשקש!",
    "No more messages" : "אין יותר הודעות",
    "Retry" : "ניסיון חוזר",
    "Unable to load the comments list" : "לא ניתן לטעון את רשימת התגובות",
    "_%n unread comment_::_%n unread comments_" : ["תגובה אחת שלא נקראה","%n תגובות שלא נקראו","%n תגובות שלא נקראו","%n תגובות שלא נקראו"],
    "_1 new comment_::_{unread} new comments_" : ["הערה חדשה אחת","{unread} הערות חדשות","{unread} הערות חדשות","{unread} הערות חדשות"],
    "Comment" : "תגובה",
    "An error occurred while trying to edit the comment" : "אירעה שגיאה בניסיון לערוך את התגובה",
    "Comment deleted" : "נמחקה הערה",
    "An error occurred while trying to delete the comment" : "אירעה שגיאה בניסיון למחוק את התגובה",
    "An error occurred while trying to create the comment" : "אירעה שגיאה בניסיון ליצור את התגובה",
    "New comment …" : "תגובה חדשה",
    "Post" : "פרסום",
    "Cancel" : "ביטול",
    "[Deleted user]" : "[משתמשים מוסרים]",
    "More comments …" : "תגובות נוספות…",
    "Save" : "שמירה",
    "Allowed characters {count} of {max}" : "תווים מותרים {count} מתוך {max}",
    "Error occurred while retrieving comment with ID {id}" : "אירעה שגיאה בעת קבלת התגובה עם המזהה {id}",
    "Error occurred while updating comment with id {id}" : "שגיאה אירעה כאשר עודכנה תגובה עם מספר זיהוי {id}",
    "Error occurred while posting comment" : "אירעה שגיאה בזמן פרסום תגובה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
